@@ -103,6 +103,16 @@ class LockState(Enum):
     unknown = 6
 
 
+def _interval_to_datetime(
+    timeout: Optional[Interval] = None,
+) -> Optional[datetime]:
+    if timeout is None:
+        return None
+    if isinstance(timeout, int):
+        timeout = timedelta(seconds=timeout)
+    return datetime.now() + timeout
+
+
 @public
 class Lock:
     """Portable, NFS-safe file locking with timeouts for POSIX systems.
@@ -161,6 +171,9 @@ class Lock:
     :param separator: The separator character to use in the lock file's
         file name.  Defaults to the vertical bar (`|`) on POSIX systems
         and caret (`^`) on Windows.
+    :param default_timeout: Default timeout for approximately how long the lock
+        acquisition attempt should be made. The value given in the `.lock()`
+        call always overrides this.
     """
 
     def __init__(
@@ -168,12 +181,14 @@ class Lock:
         lockfile: str,
         lifetime: Optional[Interval] = None,
         separator: str = SEP,
+        default_timeout: Optional[Interval] = None,
     ):
         """Create the resource lock using the given file name and lifetime."""
         # The hostname has to be defined before we call _set_claimfile().
         self._hostname = socket.getfqdn()
         if lifetime is None:
             lifetime = DEFAULT_LOCK_LIFETIME
+        self._default_timeout = default_timeout
         self._lockfile = lockfile
         # https://github.com/python/mypy/issues/3004
         self.lifetime = lifetime                    # type: ignore
@@ -306,10 +321,9 @@ class Lock:
         :raises TimeOutError: if ``timeout`` is not None and the indicated
             time interval expires without a lock acquisition.
         """
-        if timeout is not None:
-            if isinstance(timeout, int):
-                timeout = timedelta(seconds=timeout)
-            timeout_time = datetime.now() + timeout
+        timeout_time = _interval_to_datetime(
+            self._default_timeout if timeout is None else timeout
+        )
         # Make sure the claim file exists, and that its contents are current.
         self._write()
         # XXX This next call can fail with an EPERM.  I have no idea why, but
@@ -366,7 +380,7 @@ class Lock:
                 pass
             # We did not acquire the lock, because someone else already has
             # it.  Have we timed out in our quest for the lock?
-            if timeout is not None and timeout_time < datetime.now():
+            if timeout_time is not None and timeout_time < datetime.now():
                 os.unlink(self._claimfile)
                 log.error('timed out')
                 raise TimeOutError('Could not acquire the lock')
@@ -565,7 +579,23 @@ class Lock:
 
     def _break(self) -> None:
         """Break the lock."""
-        # First, touch the lock file.  This reduces but does not eliminate the
+        # Try to read from the lock file.  All we care about is that its
+        # contents have the details expected of any lock file.  If not, then
+        # this probably isn't a lock that needs breaking, it's a Lock with a
+        # lock file pointing to an existing, unrelated file.  Refuse to break
+        # that lock.  All we really need to do is to log and return.  If a
+        # timeout was given, eventually the .lock() call will timeout.
+        # However if no timeout was given, the .lock() will block forever.
+        try:
+            self.details
+        except NotLockedError:
+            log.error(
+                "lockfile exists but isn't safe to break: {}".format(
+                    self._lockfile
+                )
+            )
+            return
+        # Touch the lock file.  This reduces but does not eliminate the
         # chance for a race condition during breaking.  Two processes could
         # both pass the test for lock expiry in lock() before one of them gets
         # to touch the lock file.  This shouldn't be too bad because all
